PreTeXt Integration
===================

This is the home for now, for the database intgration that we need to do in order
for runestone to host a pretext book.  The folder includes a script that will be integrated
into the main runestone command, as well as an example runestone-manifest.xml file produced by
the pretext processor.

See `PreTeXt Book <https://pretextbook.org>` site for more details on PreTeXt.
